@@ -34,6 +34,9 @@ WXPL_EXTERN_C_END
 #undef Copy
 #undef New
 #undef Pause
+#undef Mkdir
+#undef Seek
+#undef Stat
 #if defined( __WXMSW__ )
 #undef read
 #undef write
