@@ -5,7 +5,7 @@
 ## Modified by:
 ## Created:     25/11/2000
 ## RCS-ID:      
-## Copyright:   (c) 2000 Mattia Barbon
+## Copyright:   (c) 2000-2002 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -32,8 +32,11 @@ sub new {
     $theapp = $this;
   }
 
-  Wx::_App::Start($this,$this->can('OnInit')) ||
-      Wx::_croak( 'OnInit must return a return value' );
+  $this->SetAppName($_[0]); # reasonable default for Wx::ConfigBase::Get
+
+  my $ret = Wx::_App::Start($this,$this->can('OnInit'));
+  Wx::_croak( 'OnInit must return a true return value' )
+    unless $ret || Wx::wxMAC(); # why does OnInit always return 0 on Mac?
 
   $this;
 }
